@@ -2,7 +2,7 @@ package MVC::Neaf::Util;
 
 use strict;
 use warnings;
-our $VERSION = 0.23;
+our $VERSION = 0.24;
 
 =head1 NAME
 
@@ -10,7 +10,8 @@ MVC::Neaf::Util - Some static functions for Not Even A Framework
 
 =head1 DESCRIPTION
 
-This module is probably of no use by itself. See L<MVC::Neaf>.
+This is utility class.
+Nothing to see here unless one intends to work on L<MVC::Neaf> itself.
 
 =head1 EXPORT
 
@@ -18,33 +19,18 @@ This module optionally exports anything it has.
 
 =cut
 
+use Carp;
 use parent qw(Exporter);
 our @EXPORT_OK = qw(
     canonize_path http_date path_prefixes rex run_all run_all_nodie
     JSON encode_json decode_json
-    maybe_list
+    maybe_list supported_methods extra_missing
 );
+our @CARP_NOT;
 
 # use JSON::MaybeXS; # not now, see JSON() below
 
-=head2 http_date
-
-Return a date in format required by HTTP standard for cookies
-and cache expiration.
-
-    Expires=Wed, 13 Jan 2021 22:23:01 GMT;
-
-=cut
-
-# Yay premature optimization - use ad-hoc weekdays because locale is so botched
-my @week = qw( Sun Mon Tue Wed Thu Fri Sat );
-my @month = qw( Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec );
-sub http_date {
-    my $t = shift;
-    my @date = gmtime($t);
-    return sprintf( "%s, %02d %s %04d %02d:%02d:%02d GMT"
-        , $week[$date[6]], $date[3], $month[$date[4]], 1900+$date[5], @date[2,1,0]);
-};
+# Alphabetic order, please
 
 =head2 canonize_path( path, want_slash )
 
@@ -68,6 +54,81 @@ sub canonize_path {
     return $path;
 };
 
+=head2 extra_missing
+
+    extra_missing( \%input, \%allowed, \@required )
+
+Dies if %input doesn't pass validation.
+Only definedness is checked.
+
+=cut
+
+# Now this MUST be an existing module, right?
+sub extra_missing {
+    my ($input, $allowed, $required) = @_;
+
+    my @extra   = $allowed  ? grep { !$allowed->{$_} } keys %$input : ();
+    my @missing = $required ? grep { !defined $input->{$_} } @$required : ();
+
+    if (@extra+@missing) {
+        my @stack = caller(1);
+        my @msg;
+        push @msg, "missing required fields: ".join ",", @missing
+            if @missing;
+        push @msg, "unknown fields present: ".join ",", @extra
+            if @extra;
+
+        my $fun = $stack[3];
+        $fun =~ s/^(.*)::/$1->/;
+
+        local @CARP_NOT = $stack[0];
+        croak "$fun: ".join "; ", @msg;
+    };
+};
+
+=head2 http_date
+
+Return a date in format required by HTTP standard for cookies
+and cache expiration.
+
+    Expires=Wed, 13 Jan 2021 22:23:01 GMT;
+
+=cut
+
+# Yay premature optimization - use ad-hoc weekdays because locale is so botched
+# The "proper" way to do it is to set locale to C, call strftime,
+#     and reset locale to whatever it was.
+my @week = qw( Sun Mon Tue Wed Thu Fri Sat );
+my @month = qw( Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec );
+sub http_date {
+    my $t = shift;
+    my @date = gmtime($t);
+    return sprintf( "%s, %02d %s %04d %02d:%02d:%02d GMT"
+        , $week[$date[6]], $date[3], $month[$date[4]], 1900+$date[5], @date[2,1,0]);
+};
+
+=head2 maybe_list
+
+    maybe_list( $value, @defaults )
+
+If C<$value> is C<undef>, return a copy of \@defaults.
+
+If C<$value> is a list, return a copy of it.
+
+Otherwise, return C<[ $value ]>.
+
+=cut
+
+sub maybe_list {
+    my $item = shift;
+
+    my @ret = defined $item ? (
+        ref $item eq 'ARRAY' ? @$item : ($item)
+    ) : @_;
+
+    return wantarray ? @ret : \@ret;
+};
+
 =head2 path_prefixes ($path)
 
 List ('', '/foo', '/foo/bar') for '/foo/bar'
@@ -138,27 +199,14 @@ sub run_all_nodie {
     return $dead;
 };
 
-=head2 maybe_list
-
-    maybe_list( \$value, @defaults )
-
-If C<$value> is C<undef>, replace is with a copy of \@defaults.
-
-If C<$value> is a list, leave it as is.
-
-Otherwise, replace C<$value> with C<[ $value ]>.
+=head2 supported_methods
 
 =cut
 
-sub maybe_list {
-    my ($scalref, @default) = @_;
-
-    if (ref $$scalref ne 'ARRAY') {
-        my $array = defined $$scalref ? [ my $tmp = $$scalref ] : \@default;
-        $$scalref = $array;
-    };
-
-    return $$scalref;
+# TODO 0.90 configurable or somthing
+@MVC::Neaf::supported_methods = qw( GET HEAD POST PATCH PUT DELETE );
+sub supported_methods {
+    return @MVC::Neaf::supported_methods;
 };
 
 =head2 JSON()
