@@ -2,7 +2,7 @@ package MVC::Neaf::Util::Container;
 
 use strict;
 use warnings;
-our $VERSION = '0.2800_01';
+our $VERSION = 0.24;
 
 =head1 NAME
 
@@ -35,8 +35,7 @@ and extract them in the needed order.
 use Carp;
 
 use parent qw(MVC::Neaf::Util::Base);
-use MVC::Neaf::Util qw( maybe_list canonize_path path_prefixes supported_methods check_path );
-our @CARP_NOT = qw(MVC::Neaf::Route);
+use MVC::Neaf::Util qw( maybe_list canonize_path path_prefixes supported_methods );
 
 =head1 ATTRIBUTES
 
@@ -83,13 +82,13 @@ sub store {
         if $opt{tentative} and $opt{override};
 
     $opt{data} = $data;
+    maybe_list( \$opt{path}, '' );
 
     my @methods = map { uc $_ } maybe_list( $opt{method}, supported_methods() );
 
-    my @todo = check_path map { canonize_path( $_ ) } maybe_list( $opt{path}, '' );
+    my @todo = map { canonize_path( $_ ) } maybe_list( $opt{path}, '' );
     if ($opt{exclude}) {
-        my $rex = join '|', map { quotemeta(canonize_path($_)) }
-            check_path maybe_list( $opt{exclude} );
+        my $rex = join '|', map { quotemeta(canonize_path($_)) } maybe_list($opt{exclude} );
         $opt{exclude} = qr(^(?:$rex)(?:[/?]|$));
         @todo = grep { $_ !~ $opt{exclude} } @todo
     };
@@ -217,8 +216,7 @@ Same as fetch(), but only return the last (last added & longest path) element.
 
 sub fetch_last {
     my $self = shift;
-    my ($bucket) = reverse $self->fetch_raw(@_);
-    return $bucket->{data};
+    return [ $self->fetch_raw(@_) ]->[-1]{data};
 };
 
 =head2 fetch_raw
@@ -262,7 +260,7 @@ sub fetch_raw {
 
 This module is part of L<MVC::Neaf> suite.
 
-Copyright 2016-2023 Konstantin S. Uvarin C<khedin@cpan.org>.
+Copyright 2016-2018 Konstantin S. Uvarin C<khedin@cpan.org>.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
